pub struct SymbolicConstraints<F> {
pub constraints: Vec<SymbolicExpression<F>>,
pub interactions: Vec<SymbolicInteraction<F>>,
}Expand description
Symbolic constraints for a single AIR with interactions.
Fields
constraints: Vec<SymbolicExpression<F>>All plain AIR constraints. These do not include interaction constraints that are proven via LogUp-GKR.
interactions: Vec<SymbolicInteraction<F>>Symbolic representation of interactions. These are converted into a LogUp fractional sum which must be proven using GKR.
Implementations
Sourceimpl<F: Field> SymbolicConstraints<F>
impl<F: Field> SymbolicConstraints<F>
pub fn max_constraint_degree(&self) -> usize
Sourcepub fn max_interaction_degrees(&self) -> (usize, usize)
pub fn max_interaction_degrees(&self) -> (usize, usize)
Returns the maximum field degree and count degree across all interactions