#[repr(C)]pub struct SymbolicConstraintsDag<F> {
pub constraints: SymbolicExpressionDag<F>,
pub interactions: Vec<Interaction<usize>>,
}Fields
constraints: SymbolicExpressionDag<F>DAG with all symbolic expressions as nodes.
These nodes include expressions for plain AIR constraints as well as symbolic expressions
used for interactions.
interactions: Vec<Interaction<usize>>List of all interactions, where expressions in the interactions
are referenced by node idx as usize.
These expressions are converted into a LogUp fractional sum which must be proven using GKR.